AppTheme class

Constructors

AppTheme({required String name, required Brightness brightness, required Color primaryColor, required Color accentColor, required Color scaffoldBackgroundColor, required Color backgroundColor, required Color cardColor, required Color textColor, required Color secondaryTextColor, Map<String, dynamic> customStyles = const {}})
const

Properties

accentColor Color
final
backgroundColor Color
final
brightness Brightness
final
cardColor Color
final
customStyles Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffoldBackgroundColor Color
final
secondaryTextColor Color
final
textColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toThemeData() ThemeData

Operators

operator ==(Object other) bool
The equality operator.
inherited